@@ -496,8 +496,7 @@ static int openConnectionCount = 0;
                             adaptorChannel:self];
     }
     if (value == nil) {
-      NSLog(@"ERROR(%s): %@: got no value for column:\n"
-            @"  attribute=%@\n  valueClass=%@\n  type=%@",
+      NSLog(@"ERROR(%s): %@: got no value for column: attribute=%@\n  valueClass=%@\n  type=%@",
             __PRETTY_FUNCTION__, self,
             attrName, NSStringFromClass(valueClass), 
             [attribute externalType]);
