@@ -720,6 +720,9 @@ static void freeMods(LDAPMod **mods) {
   
   if (msgid == -1) {
     /* trouble */
+    int err;
+    ldap_get_option(self->handle, LDAP_OPT_RESULT_CODE, &err);
+    NSLog(@"Fatal LDAP error during ldap_search: %s", ldap_err2string(err));
     return nil;
   }
 
